<TS language="ka" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation>დააჭირეთ მარჯვენა ღილაკს მისამართის ან იარლიყის ჩასასწორებლად</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>ახალი მისამართის შექმნა</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>შექმ&amp;ნა</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>მონიშნული მისამართის კოპირება სისტემურ კლიპბორდში</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;კოპირება</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>&amp;დახურვა</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>მონიშნული მისამართის წაშლა სიიდან</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation>შეიყვანეთ საძებნი მისამართი ან ნიშნული</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>ამ ბარათიდან მონაცემების ექსპორტი ფაილში</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;ექსპორტი</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;წაშლა</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>აირჩიეთ კოინების გამგზავნი მისამართი</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>აირჩიეთ კოინების მიმღები მისამართი</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>&amp;არჩევა</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>გამმგზავნი მისამართ</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>მიმღები მისამართი</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>ეს არის თქვენი ბიტკოინ-მისამართები, რომელთაგანაც შეგიძლიათ გადახდა. აუცილებლად შეამოწმეთ თანხა და მიმღები მისამართი გაგზავნამდე.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>მისამართის კოპირება</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>ნიშნულის კოპირება</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;რედაქტირება</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>მისამართების სიის ექსპორტი</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>CSV ფორმატის ფაილი (*.csv)</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>ექპორტი ვერ განხორციელდა</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <translation>მისამართების სიის %1 შენახვა ვერ მოხერხდა. გაიმეორეთ მცდელობა.</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>ნიშნული</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>მისამართი</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(ნიშნული არ არის)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>ფრაზა-პაროლის დიალოგი</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>შეიყვანეთ ფრაზა-პაროლი</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>ახალი ფრაზა-პაროლი</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>გაიმეორეთ ახალი ფრაზა-პაროლი</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>საფულის დაშიფრვა</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>ამ ოპერაციის შესასრულებლად საჭიროა თქვენი საფულის განბლოკვა პასფრაზით.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>საფულის განბლოკვა</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>ამ ოპერაციის შესასრულებლად საჭიროა თქვენი საფულის განშიფრვა პასფრაზით.</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>საფულის განბლოკვა</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>პაროლის შეცვლა</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>საფულის დაშიფრვის დადასტურება</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation>გაფრთხილება: თუ თქვენ დაშიფრავთ თქვენს საფულეს და ამის შემდეგ დაკარგავთ გასაშიფრ ფრაზას, &lt;b&gt;თქვენ დაკარგავთ ყველა ბიტკოინს!&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>დარწმუნებული ხარ რომ საფულის დაშიფვრა გსურს?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>საფულე დაშიფრულია</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>მნიშვნელოვანი: ნებისმიერი საფულის წინა სარეზერვო კოპია, რომელიც თქვენ შექმენით, უნდა იყოს ჩანაცვლებული ახლად გენერირებული, დაშიფრული საფულის ფაილით. უსაფრთხოების მიზნებისთვის, დაუშიფრავი საფულის ფაილის წინა სარეზევო კოპიები გახდება გამოუყენებული იმ წამსვე, როდესაც დაიწყებთ ახალი, დაშიფრული საფულის გამოყენებას.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>საფულის დაშიფვრა წარუმატებით დამთვრდა</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>საფულის დაშიფრვა ვერ მოხდა შიდა შეცდომის გამო. თქვენი საფულე არ არის დაშიფრული.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>მოწოდებული ფრაზა-პაროლები არ ემთხვევა ერთმანეთს.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>საფულის გახსნა წარუმატებლად შესრულდა</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>საფულის განშიფრვის ფრაზა-პაროლი არაწორია</translation>
    </message>
    <message>
        <source>Wallet decryption failed</source>
        <translation>საფულის გაშიფვრა ვერ შესრულდა</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>საფულის ფრაზა-პაროლი შეცვლილია.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>ყურადღება: ჩართულია Caps Lock რეჟიმი!</translation>
    </message>
</context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>IP/Netmask</source>
        <translation>IP/ქსელის მასკა</translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Sign &amp;message...</source>
        <translation>ხელ&amp;მოწერა</translation>
    </message>
    <message>
        <source>Synchronizing with network...</source>
        <translation>ქსელთან სინქრონიზება...</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>მიმ&amp;ოხილვა</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>საფულის ზოგადი მიმოხილვა</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation>&amp;ტრანსაქციები</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>ტრანსაქციების ისტორიის დათვალიერება</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;გასვლა</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>გასვლა</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation>%1-ის &amp;შესახებ</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation>%1-ის შესახებ ინფორმაციის ჩვენება</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>&amp;Qt-ს შესახებ</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation>ინფორმაცია Qt-ს შესახებ</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;ოპციები</translation>
    </message>
    <message>
        <source>Modify configuration options for %1</source>
        <translation>%1-ის კონფიგურირების პარამეტრების რედაქტირება</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>საფულის &amp;დაშიფრვა</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet...</source>
        <translation>საფულის &amp;არქივირება</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>ფრაზა-პაროლის შე&amp;ცვლა</translation>
    </message>
    <message>
        <source>Open &amp;URI...</source>
        <translation>&amp;URI-ის გახსნა...</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation>საფულე:</translation>
    </message>
    <message>
        <source>Click to disable network activity.</source>
        <translation>დააწკაპეთ ქსელური აქტივობის გასათიშად.</translation>
    </message>
    <message>
        <source>Network activity disabled.</source>
        <translation>ქსელური აქტივობა გათიშულია.</translation>
    </message>
    <message>
        <source>Reindexing blocks on disk...</source>
        <translation>დისკზე ბლოკების რეინდექსაცია...</translation>
    </message>
    <message>
        <source>Send coins to a Bitcoin address</source>
        <translation>მონეტების გაგზავნა Bitcoin-მისამართზე</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation>საფულის არქივირება სხვა ადგილზე</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>საფულის დაშიფრვის ფრაზა-პაროლის შეცვლა</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;ვერიფიკაცია</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;გაგზავნა</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;მიღება</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;ჩვენება/დაფარვა</translation>
    </message>
    <message>
        <source>Show or hide the main Window</source>
        <translation>მთავარი ფანჯრის ჩვენება/დაფარვა</translation>
    </message>
    <message>
        <source>Encrypt the private keys that belong to your wallet</source>
        <translation>თქვენი საფულის პირადი გასაღებების დაშიფრვა</translation>
    </message>
    <message>
        <source>Sign messages with your Bitcoin addresses to prove you own them</source>
        <translation>მესიჯებზე ხელმოწერა თქვენი Bitcoin-მისამართებით იმის დასტურად, რომ ის თქვენია</translation>
    </message>
    <message>
        <source>Verify messages to ensure they were signed with specified Bitcoin addresses</source>
        <translation>შეამოწმეთ, რომ მესიჯები ხელმოწერილია მითითებული Bitcoin-მისამართით</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;ფაილი</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;პარამეტრები</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;დახმარება</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation>ბარათების პანელი</translation>
    </message>
    <message>
        <source>Request payments (generates QR codes and bitcoin: URIs)</source>
        <translation>გადახდის მოთხოვნა (შეიქმნება QR-კოდები და bitcoin: ბმულები)</translation>
    </message>
    <message>
        <source>Show the list of used sending addresses and labels</source>
        <translation>გამოყენებული გაგზავნის მისამართებისა და ნიშნულების სიის ჩვენება</translation>
    </message>
    <message>
        <source>Show the list of used receiving addresses and labels</source>
        <translation>გამოყენებული მიღების მისამართებისა და ნიშნულების სიის ჩვენება</translation>
    </message>
    <message>
        <source>&amp;Command-line options</source>
        <translation>საკომანდო სტრიქონის ოპ&amp;ციები</translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation>%1 გავლილია</translation>
    </message>
    <message>
        <source>Last received block was generated %1 ago.</source>
        <translation>ბოლო მიღებული ბლოკის გენერირებიდან გასულია %1</translation>
    </message>
    <message>
        <source>Transactions after this will not yet be visible.</source>
        <translation>შემდგომი ტრანსაქციები ნაჩვენები ჯერ არ იქნება.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>შეცდომა</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>გაფრთხილება</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>ინფორმაცია</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>განახლებულია</translation>
    </message>
    <message>
        <source>default wallet</source>
        <translation>ნაგულისხმევი საფულე</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;ფანჯარა</translation>
    </message>
    <message>
        <source>%1 client</source>
        <translation>%1 კლიენტი</translation>
    </message>
    <message>
        <source>Connecting to peers...</source>
        <translation>შეერთება ქსელთან...</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>ჩართვა...</translation>
    </message>
    <message>
        <source>Date: %1
</source>
        <translation>თარიღი: %1
</translation>
    </message>
    <message>
        <source>Amount: %1
</source>
        <translation>რაოდენობა^ %1
</translation>
    </message>
    <message>
        <source>Wallet: %1
</source>
        <translation>საფულე: %1
</translation>
    </message>
    <message>
        <source>Type: %1
</source>
        <translation>ტიპი: %1
</translation>
    </message>
    <message>
        <source>Label: %1
</source>
        <translation>ლეიბლი: %1
</translation>
    </message>
    <message>
        <source>Address: %1
</source>
        <translation>მისამართი: %1
</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>გაგზავნილი ტრანსაქციები</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>მიღებული ტრანსაქციები</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;unlocked&lt;/b&gt;</source>
        <translation>საფულე &lt;b&gt;დაშიფრულია&lt;/b&gt; და ამჟამად &lt;b&gt;განბლოკილია&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>საფულე &lt;b&gt;დაშიფრულია&lt;/b&gt; და ამჟამად &lt;b&gt;დაბლოკილია&lt;/b&gt;</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>რაოდენობა:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>ბაიტები:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>თანხა:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>საკომისიო:</translation>
    </message>
    <message>
        <source>Dust:</source>
        <translation>მტვერი:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>დამატებითი საკომისიო:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>ხურდა:</translation>
    </message>
    <message>
        <source>(un)select all</source>
        <translation>ყველას მონიშვნა/(მოხსნა)</translation>
    </message>
    <message>
        <source>Tree mode</source>
        <translation>განტოტვილი</translation>
    </message>
    <message>
        <source>List mode</source>
        <translation>სია</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>თანხა</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>თარიღი</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>დადასტურება</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>დადასტურებულია</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>მისამართის კოპირება</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>ლეიბლის კოპირება</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>რაოდენობის კოპირება</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>ტრანსაქციის ID-ს კოპირება</translation>
    </message>
    <message>
        <source>Lock unspent</source>
        <translation>დაუხარჯავის ჩაკეტვა</translation>
    </message>
    <message>
        <source>Unlock unspent</source>
        <translation>დაუხარჯავის განბლოკვა</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>რაოდენობის კოპირება</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>საკომისიოს კოპირება</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>დამატებითი საკომისიოს კოპირება</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>ბაიტების კოპირება</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>ხურდის კოპირება</translation>
    </message>
    <message>
        <source>(%1 locked)</source>
        <translation>(%1 დაბლოკილია)</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>დიახ</translation>
    </message>
    <message>
        <source>no</source>
        <translation>არა</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(ნიშნული არ არის)</translation>
    </message>
    <message>
        <source>change from %1 (%2)</source>
        <translation>ხურდა %1-დან (%2)</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation>(ხურდა)</translation>
    </message>
</context>
<context>
    <name>CreateWalletActivity</name>
    </context>
<context>
    <name>CreateWalletDialog</name>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>მისამართის შეცვლა</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>ნიშნუ&amp;ლი</translation>
    </message>
    <message>
        <source>The label associated with this address list entry</source>
        <translation>მისამართების სიის ამ ჩანაწერთან ასოცირებული ნიშნული</translation>
    </message>
    <message>
        <source>The address associated with this address list entry. This can only be modified for sending addresses.</source>
        <translation>მისამართების სიის ამ ჩანაწერთან მისამართი ასოცირებული. მისი შეცვლა შეიძლება მხოლოდ გაგზავნის მისამართის შემთხვევაში.</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>მის&amp;ამართი</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>ახალი გაგზავნის მისამართი</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>მიღების მისამართის შეცვლა</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>გაგზავნის მისამართის შეცვლა</translation>
    </message>
    <message>
        <source>The entered address "%1" is not a valid Bitcoin address.</source>
        <translation>შეყვანილი მისამართი "%1" არ არის ვალიდური Bitcoin-მისამართი.</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>საფულის განბლოკვა ვერ მოხერხდა.</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>ახალი გასაღების გენერირება ვერ მოხერხდა</translation>
    </message>
</context>
<context>
    <name>FreespaceChecker</name>
    <message>
        <source>A new data directory will be created.</source>
        <translation>შეიქმნება ახალი მონაცემთა კატალოგი.</translation>
    </message>
    <message>
        <source>name</source>
        <translation>სახელი</translation>
    </message>
    <message>
        <source>Directory already exists. Add %1 if you intend to create a new directory here.</source>
        <translation>კატალოგი უკვე არსებობს. დაამატეთ %1 თუ გინდათ ახალი კატალოგის აქვე შექმნა.</translation>
    </message>
    <message>
        <source>Path already exists, and is not a directory.</source>
        <translation>მისამართი უკვე არსებობს და არ წარმოადგენს კატალოგს.</translation>
    </message>
    <message>
        <source>Cannot create data directory here.</source>
        <translation>კატალოგის აქ შექმნა შეუძლებელია.</translation>
    </message>
</context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>version</source>
        <translation>ვერსია</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation>%1-ის შესახებ</translation>
    </message>
    <message>
        <source>Command-line options</source>
        <translation>კომანდების ზოლის ოპციები</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message>
        <source>Welcome</source>
        <translation>მოგესალმებით</translation>
    </message>
    <message>
        <source>Welcome to %1.</source>
        <translation>კეთილი იყოს თქვენი მობრძანება %1-ში.</translation>
    </message>
    <message>
        <source>Use the default data directory</source>
        <translation>ნაგულისხმევი კატალოგის გამოყენება</translation>
    </message>
    <message>
        <source>Use a custom data directory:</source>
        <translation>მითითებული კატალოგის გამოყენება:</translation>
    </message>
    <message>
        <source>Bitcoin</source>
        <translation>Bitcoin</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>შეცდომა</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Form</source>
        <translation>ფორმა</translation>
    </message>
    <message>
        <source>Unknown...</source>
        <translation>უცნობი...</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>ბოლო ბლოკის დრო</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>პროგრესი</translation>
    </message>
    <message>
        <source>calculating...</source>
        <translation>მიმდინარეობს გამოთვლა...</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>დამალვა</translation>
    </message>
    </context>
<context>
    <name>OpenURIDialog</name>
    <message>
        <source>URI:</source>
        <translation>URI:</translation>
    </message>
</context>
<context>
    <name>OpenWalletActivity</name>
    <message>
        <source>default wallet</source>
        <translation>ნაგულისხმევი საფულე</translation>
    </message>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>ოპციები</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>&amp;მთავარი</translation>
    </message>
    <message>
        <source>Size of &amp;database cache</source>
        <translation>მონაცემთა ბაზის კეშის სი&amp;დიდე</translation>
    </message>
    <message>
        <source>Number of script &amp;verification threads</source>
        <translation>სკრიპტის &amp;ვერიფიცირების ნაკადების რაოდენობა</translation>
    </message>
    <message>
        <source>IP address of the proxy (e.g. IPv4: 127.0.0.1 / IPv6: ::1)</source>
        <translation>პროქსის IP-მისამართი (მაგ.: IPv4: 127.0.0.1 / IPv6: ::1)</translation>
    </message>
    <message>
        <source>Reset all client options to default.</source>
        <translation>კლიენტის ყველა პარამეტრის დაბრუნება ნაგულისხმევ მნიშვნელობებზე.</translation>
    </message>
    <message>
        <source>&amp;Reset Options</source>
        <translation>დაბ&amp;რუნების ოპციები</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;ქსელი</translation>
    </message>
    <message>
        <source>W&amp;allet</source>
        <translation>ს&amp;აფულე</translation>
    </message>
    <message>
        <source>Expert</source>
        <translation>ექსპერტი</translation>
    </message>
    <message>
        <source>If you disable the spending of unconfirmed change, the change from a transaction cannot be used until that transaction has at least one confirmation. This also affects how your balance is computed.</source>
        <translation>დაუდასტურებელი ხურდის გამოყენების აკრძალვის შემდეგ მათი გამოყენება შეუძლებელი იქნება, სანამ ტრანსაქციას არ ექნება ერთი დასტური მაინც. ეს აისახება თქვენი ნაშთის დათვლაზეც.</translation>
    </message>
    <message>
        <source>Automatically open the Bitcoin client port on the router. This only works when your router supports UPnP and it is enabled.</source>
        <translation>როუტერში Bitcoin-კლიენტის პორტის ავტომატური გახსნა. მუშაობს, თუ თქვენს როუტერს ჩართული აქვს UPnP.</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>პორტის გადამისამართება &amp;UPnP-ით</translation>
    </message>
    <message>
        <source>Proxy &amp;IP:</source>
        <translation>პროქსის &amp;IP:</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation>&amp;პორტი</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation>პროქსის პორტი (მაგ.: 9050)</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Tor</source>
        <translation>Tor</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;ფანჯარა</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation>ფანჯრის მინიმიზებისას მხოლოდ იკონა სისტემურ ზონაში</translation>
    </message>
    <message>
        <source>&amp;Minimize to the tray instead of the taskbar</source>
        <translation>&amp;მინიმიზება სისტემურ ზონაში პროგრამების პანელის ნაცვლად</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation>მ&amp;ინიმიზება დახურვისას</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;ჩვენება</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation>სამომხმარებ&amp;ლო ენა:</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation>ერთეუ&amp;ლი:</translation>
    </message>
    <message>
        <source>Choose the default subdivision unit to show in the interface and when sending coins.</source>
        <translation>აირჩიეთ გასაგზავნი თანხის ნაგულისხმევი ერთეული.</translation>
    </message>
    <message>
        <source>Whether to show coin control features or not.</source>
        <translation>ვაჩვენოთ თუ არა მონეტების მართვის პარამეტრები.</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;გაუქმება</translation>
    </message>
    <message>
        <source>default</source>
        <translation>ნაგულისხმევი</translation>
    </message>
    <message>
        <source>none</source>
        <translation>ცარიელი</translation>
    </message>
    <message>
        <source>Confirm options reset</source>
        <translation>დაადასტურეთ პარამეტრების დაბრუნება ნაგულისხმევზე</translation>
    </message>
    <message>
        <source>Client restart required to activate changes.</source>
        <translation>ცვლილებები ძალაში შევა კლიენტის ხელახალი გაშვების შემდეგ.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>შეცდომა</translation>
    </message>
    <message>
        <source>This change would require a client restart.</source>
        <translation>ამ ცვლილებების ძალაში შესასვლელად საჭიროა კლიენტის დახურვა და ხელახალი გაშვება.</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation>პროქსის მისამართი არასწორია.</translation>
    </message>
</context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>ფორმა</translation>
    </message>
    <message>
        <source>The displayed information may be out of date. Your wallet automatically synchronizes with the Bitcoin network after a connection is established, but this process has not completed yet.</source>
        <translation>ნაჩვენები ინფორმაცია შეიძლება მოძველებული იყოს. თქვენი საფულე ავტომატურად სინქრონიზდება Bitcoin-ის ქსელთან კავშირის დამყარების შემდეგ, ეს პროცესი ჯერ არ არის დასრულებული.</translation>
    </message>
    <message>
        <source>Available:</source>
        <translation>ხელმისაწვდომია:</translation>
    </message>
    <message>
        <source>Your current spendable balance</source>
        <translation>თქვენი ხელმისაწვდომი ნაშთი</translation>
    </message>
    <message>
        <source>Pending:</source>
        <translation>იგზავნება:</translation>
    </message>
    <message>
        <source>Total of transactions that have yet to be confirmed, and do not yet count toward the spendable balance</source>
        <translation>დასადასტურებელი ტრანსაქციების საერთო რაოდენობა, რომლებიც ჯერ არ არის ასახული ბალანსში</translation>
    </message>
    <message>
        <source>Immature:</source>
        <translation>მოუმზადებელია:</translation>
    </message>
    <message>
        <source>Mined balance that has not yet matured</source>
        <translation>მოპოვებული თანხა, რომელიც ჯერ არ არის მზადყოფნაში</translation>
    </message>
    <message>
        <source>Total:</source>
        <translation>სულ:</translation>
    </message>
    <message>
        <source>Your current total balance</source>
        <translation>თქვენი სრული მიმდინარე ბალანსი</translation>
    </message>
    </context>
<context>
    <name>PSBTOperationsDialog</name>
    <message>
        <source>or</source>
        <translation>ან</translation>
    </message>
    </context>
<context>
    <name>PaymentServer</name>
    <message>
        <source>Payment request error</source>
        <translation>გადახდის მოთხოვნის შეცდომა</translation>
    </message>
    <message>
        <source>Cannot start bitcoin: click-to-pay handler</source>
        <translation>ვერ გაიშვა bitcoin: click-to-pay</translation>
    </message>
    <message>
        <source>URI handling</source>
        <translation>URI-ების დამუშავება</translation>
    </message>
    <message>
        <source>Invalid payment address %1</source>
        <translation>გადახდის მისამართი არასწორია: %1</translation>
    </message>
    <message>
        <source>Payment request file handling</source>
        <translation>გადახდის მოთხოვნის ფაილის დამუშავება</translation>
    </message>
</context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>თანხა</translation>
    </message>
    <message>
        <source>%1 h</source>
        <translation>%1 სთ</translation>
    </message>
    <message>
        <source>%1 m</source>
        <translation>%1 წთ</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>მიუწვდ.</translation>
    </message>
    <message>
        <source>%1 and %2</source>
        <translation>%1 და %2</translation>
    </message>
    <message>
        <source>%1 B</source>
        <translation>%1 B</translation>
    </message>
    <message>
        <source>%1 KB</source>
        <translation>%1 KB</translation>
    </message>
    <message>
        <source>%1 MB</source>
        <translation>%1 MB</translation>
    </message>
    <message>
        <source>%1 GB</source>
        <translation>%1 GB</translation>
    </message>
    <message>
        <source>Error: Specified data directory "%1" does not exist.</source>
        <translation>შეცდომა: მითითებული მონაცემთა კატალოგი "%1" არ არსებობს.</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>უცნობია</translation>
    </message>
</context>
<context>
    <name>QRImageWidget</name>
    <message>
        <source>&amp;Save Image...</source>
        <translation>გამო&amp;სახულების შენახვა...</translation>
    </message>
    <message>
        <source>&amp;Copy Image</source>
        <translation>გამოსახულების &amp;კოპირება</translation>
    </message>
    <message>
        <source>Resulting URI too long, try to reduce the text for label / message.</source>
        <translation>URI ძალიან გრძელი გამოდის, შეამოკლეთ ნიშნულის/მესიჯის ტექსტი.</translation>
    </message>
    <message>
        <source>Error encoding URI into QR Code.</source>
        <translation>შედომა URI-ის QR-კოდში გადაყვანისას.</translation>
    </message>
    <message>
        <source>Save QR Code</source>
        <translation>QR-კოდის შენახვა</translation>
    </message>
    <message>
        <source>PNG Image (*.png)</source>
        <translation>PNG სურათი (*.png)</translation>
    </message>
</context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>N/A</source>
        <translation>მიუწვდ.</translation>
    </message>
    <message>
        <source>Client version</source>
        <translation>კლიენტის ვერსია</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation>&amp;ინფორმაცია</translation>
    </message>
    <message>
        <source>General</source>
        <translation>საერთო</translation>
    </message>
    <message>
        <source>Startup time</source>
        <translation>სტარტის დრო</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>ქსელი</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>სახელი</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation>შეერთებების რაოდენობა</translation>
    </message>
    <message>
        <source>Block chain</source>
        <translation>ბლოკთა ჯაჭვი</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>ბოლო ბლოკის დრო</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;შექმნა</translation>
    </message>
    <message>
        <source>&amp;Console</source>
        <translation>&amp;კონსოლი</translation>
    </message>
    <message>
        <source>&amp;Network Traffic</source>
        <translation>&amp;ქსელის ტრაფიკი</translation>
    </message>
    <message>
        <source>Totals</source>
        <translation>სულ:</translation>
    </message>
    <message>
        <source>In:</source>
        <translation>შემომავალი:</translation>
    </message>
    <message>
        <source>Out:</source>
        <translation>გამავალი:</translation>
    </message>
    <message>
        <source>Debug log file</source>
        <translation>დახვეწის ლოგ-ფაილი</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation>კონსოლის გასუფთავება</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Amount:</source>
        <translation>თ&amp;ანხა:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>ნიშნუ&amp;ლი:</translation>
    </message>
    <message>
        <source>&amp;Message:</source>
        <translation>&amp;მესიჯი:</translation>
    </message>
    <message>
        <source>An optional message to attach to the payment request, which will be displayed when the request is opened. Note: The message will not be sent with the payment over the Bitcoin network.</source>
        <translation>არააუცილებელი მესიჯი, რომელიც ერთვის გადახდის მოთხოვნას და ნაჩვენები იქნება მოთხოვნის გახსნისას. შენიშვნა: მესიჯი არ გაყვება გადახდას ბითქოინის ქსელში.</translation>
    </message>
    <message>
        <source>An optional label to associate with the new receiving address.</source>
        <translation>არააუცილებელი ნიშნული ახალ მიღების მისამართთან ასოცირებისათვის.</translation>
    </message>
    <message>
        <source>Use this form to request payments. All fields are &lt;b&gt;optional&lt;/b&gt;.</source>
        <translation>გამოიყენეთ ეს ფორმა გადახდის მოთხოვნისათვის. ყველა ველი &lt;b&gt;არააუცილებელია&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>An optional amount to request. Leave this empty or zero to not request a specific amount.</source>
        <translation>მოთხოვნის მოცულობა. არააუცილებელია. ჩაწერეთ 0 ან დატოვეთ ცარიელი, თუ არ მოითხოვება კონკრეტული მოცულობა.</translation>
    </message>
    <message>
        <source>Clear all fields of the form.</source>
        <translation>ფორმის ყველა ველის წაშლა</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>წაშლა</translation>
    </message>
    <message>
        <source>Requested payments history</source>
        <translation>მოთხოვნილი გადახდების ისტორია</translation>
    </message>
    <message>
        <source>Show the selected request (does the same as double clicking an entry)</source>
        <translation>არჩეული მოთხოვნის ჩვენება (იგივეა, რაც ჩანაწერზე ორჯერ ჩხვლეტა)</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>ჩვენება</translation>
    </message>
    <message>
        <source>Remove the selected entries from the list</source>
        <translation>მონიშნული ჩანაწერების წაშლა სიიდან</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>წაშლა</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>ლეიბლის კოპირება</translation>
    </message>
    <message>
        <source>Copy message</source>
        <translation>მესიჯის კოპირება</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>რაოდენობის კოპირება</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>საფულის განბლოკვა ვერ მოხერხდა.</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Amount:</source>
        <translation>თანხა:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>მესიჯი:</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation>საფულე:</translation>
    </message>
    <message>
        <source>Copy &amp;URI</source>
        <translation>&amp;URI-ის კოპირება</translation>
    </message>
    <message>
        <source>Copy &amp;Address</source>
        <translation>მის&amp;ამართის კოპირება</translation>
    </message>
    <message>
        <source>&amp;Save Image...</source>
        <translation>გამო&amp;სახულების შენახვა...</translation>
    </message>
    <message>
        <source>Request payment to %1</source>
        <translation>%1-ის გადაზდის მოთხოვნა</translation>
    </message>
    <message>
        <source>Payment information</source>
        <translation>ინფორმაცია გადახდის შესახებ</translation>
    </message>
</context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation>თარიღი</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>ნიშნული</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>მესიჯი</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(ნიშნული არ არის)</translation>
    </message>
    <message>
        <source>(no message)</source>
        <translation>(მესიჯები არ არის)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>მონეტების გაგზავნა</translation>
    </message>
    <message>
        <source>Coin Control Features</source>
        <translation>მონეტების კონტროლის პარამეტრები</translation>
    </message>
    <message>
        <source>Inputs...</source>
        <translation>ხარჯები...</translation>
    </message>
    <message>
        <source>automatically selected</source>
        <translation>არჩეულია ავტომატურად</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>არ არის საკმარისი თანხა!</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>რაოდენობა:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>ბაიტები:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>თანხა:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>საკომისიო:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>დამატებითი საკომისიო:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>ხურდა:</translation>
    </message>
    <message>
        <source>If this is activated, but the change address is empty or invalid, change will be sent to a newly generated address.</source>
        <translation>ამის გააქტიურებისას თუ ხურდის მისამართი ცარიელია ან არასწორია, ხურდა გაიგზავნება ახლად გენერირებულ მისამართებზე.</translation>
    </message>
    <message>
        <source>Custom change address</source>
        <translation>ხურდის მისამართი</translation>
    </message>
    <message>
        <source>Transaction Fee:</source>
        <translation>ტრანსაქციის საფასური - საკომისიო:</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>დამალვა</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>გაგზავნა რამდენიმე რეციპიენტთან ერთდროულად</translation>
    </message>
    <message>
        <source>Add &amp;Recipient</source>
        <translation>&amp;რეციპიენტის დამატება</translation>
    </message>
    <message>
        <source>Clear all fields of the form.</source>
        <translation>ფორმის ყველა ველის წაშლა</translation>
    </message>
    <message>
        <source>Dust:</source>
        <translation>მტვერი:</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>გ&amp;ასუფთავება</translation>
    </message>
    <message>
        <source>Balance:</source>
        <translation>ბალანსი:</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>გაგზავნის დადასტურება</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>გაგ&amp;ზავნა</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>რაოდენობის კოპირება</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>რაოდენობის კოპირება</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>საკომისიოს კოპირება</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>დამატებითი საკომისიოს კოპირება</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>ბაიტების კოპირება</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>ხურდის კოპირება</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>%1-დან %2-ში</translation>
    </message>
    <message>
        <source>Are you sure you want to send?</source>
        <translation>დარწმუნებული ხართ, რომ გინდათ გაგზავნა?</translation>
    </message>
    <message>
        <source>or</source>
        <translation>ან</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>ტრანსაქციის საფასური - საკომისიო</translation>
    </message>
    <message>
        <source>Confirm send coins</source>
        <translation>მონეტების გაგზავნის დადასტურება</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation>გადახდის მოცულობა 0-ზე მეტი უნდა იყოს</translation>
    </message>
    <message>
        <source>The amount exceeds your balance.</source>
        <translation>თანხა აღემატება თქვენს ბალანსს</translation>
    </message>
    <message>
        <source>The total exceeds your balance when the %1 transaction fee is included.</source>
        <translation>საკომისიო %1-ის დამატების შემდეგ თანხა აჭარბებს თქვენს ბალანსს</translation>
    </message>
    <message>
        <source>Transaction creation failed!</source>
        <translation>შეცდომა ტრანსაქციის შექმნისას!</translation>
    </message>
    <message>
        <source>Warning: Invalid Bitcoin address</source>
        <translation>ყურადღება: არასწორია Bitcoin-მისამართი</translation>
    </message>
    <message>
        <source>Warning: Unknown change address</source>
        <translation>ყურადღება: უცნობია ხურდის მისამართი</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(ნიშნული არ არის)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>&amp;რაოდენობა</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>ადრესა&amp;ტი:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>ნიშნუ&amp;ლი:</translation>
    </message>
    <message>
        <source>Choose previously used address</source>
        <translation>აირჩიეთ ადრე გამოყენებული მისამართი</translation>
    </message>
    <message>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>მისამართის ჩასმა კლიპბორდიდან</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt+P</translation>
    </message>
    <message>
        <source>Remove this entry</source>
        <translation>ჩანაწერის წაშლა</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>მესიჯი:</translation>
    </message>
    <message>
        <source>Enter a label for this address to add it to the list of used addresses</source>
        <translation>შეიყვანეთ ამ მისამართის ნიშნული გამოყენებული მისამართების სიაში დასამატებლად</translation>
    </message>
    <message>
        <source>A message that was attached to the bitcoin: URI which will be stored with the transaction for your reference. Note: This message will not be sent over the Bitcoin network.</source>
        <translation>მესიჯი, რომელიც თან ერთვის მონეტებს:  URI, რომელიც შეინახება ტრანსაქციასთან ერთად თქვენთვის. შენიშვნა: მესიჯი არ გაყვება გადახდას ბითქოინის ქსელში.</translation>
    </message>
    <message>
        <source>Pay To:</source>
        <translation>ადრესატი:</translation>
    </message>
    <message>
        <source>Memo:</source>
        <translation>შენიშვნა:</translation>
    </message>
</context>
<context>
    <name>ShutdownWindow</name>
    <message>
        <source>Do not shut down the computer until this window disappears.</source>
        <translation>არ გამორთოთ კომპიუტერი ამ ფანჯრის გაქრობამდე.</translation>
    </message>
</context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Signatures - Sign / Verify a Message</source>
        <translation>ხელმოწერები - მესიჯის ხელმოწერა/ვერიფიკაცია</translation>
    </message>
    <message>
        <source>&amp;Sign Message</source>
        <translation>მე&amp;სიჯის ხელმოწერა</translation>
    </message>
    <message>
        <source>Choose previously used address</source>
        <translation>აირჩიეთ ადრე გამოყენებული მისამართი</translation>
    </message>
    <message>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>მისამართის ჩასმა კლიპბორდიდან</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt+P</translation>
    </message>
    <message>
        <source>Enter the message you want to sign here</source>
        <translation>აკრიფეთ ხელმოსაწერი მესიჯი</translation>
    </message>
    <message>
        <source>Signature</source>
        <translation>ხელმოწერა</translation>
    </message>
    <message>
        <source>Copy the current signature to the system clipboard</source>
        <translation>მიმდინარე ხელმოწერის კოპირება კლიპბორდში</translation>
    </message>
    <message>
        <source>Sign the message to prove you own this Bitcoin address</source>
        <translation>მოაწერეთ ხელი იმის დასადასტურებლად, რომ ეს მისამართი თქვენია</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>&amp;მესიჯის ხელმოწერა</translation>
    </message>
    <message>
        <source>Reset all sign message fields</source>
        <translation>ხელმოწერის ყველა ველის წაშლა</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>გ&amp;ასუფთავება</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>მესიჯის &amp;ვერიფიკაცია</translation>
    </message>
    <message>
        <source>Verify the message to ensure it was signed with the specified Bitcoin address</source>
        <translation>შეამოწმეთ, რომ მესიჯი ხელმოწერილია მითითებული Bitcoin-მისამართით</translation>
    </message>
    <message>
        <source>Verify &amp;Message</source>
        <translation>&amp;მესიჯის ვერიფიკაცია</translation>
    </message>
    <message>
        <source>Reset all verify message fields</source>
        <translation>ვერიფიკაციის ყველა ველის წაშლა</translation>
    </message>
    <message>
        <source>Click "Sign Message" to generate signature</source>
        <translation>ხელმოწერის გენერირებისათვის დააჭირეთ "მესიჯის ხელმოწერა"-ს</translation>
    </message>
    <message>
        <source>The entered address is invalid.</source>
        <translation>შეყვანილი მისამართი არასწორია.</translation>
    </message>
    <message>
        <source>Please check the address and try again.</source>
        <translation>შეამოწმეთ მისამართი და სცადეთ ხელახლა.</translation>
    </message>
    <message>
        <source>The entered address does not refer to a key.</source>
        <translation>შეყვანილი მისამართი არ არის კავშირში გასაღებთან.</translation>
    </message>
    <message>
        <source>Wallet unlock was cancelled.</source>
        <translation>საფულის განბლოკვა შეწყვეტილია.</translation>
    </message>
    <message>
        <source>Private key for the entered address is not available.</source>
        <translation>ამ მისამართისათვის პირადი გასაღები მიუწვდომელია.</translation>
    </message>
    <message>
        <source>Message signing failed.</source>
        <translation>ვერ მოხერხდა მესიჯის ხელმოწერა.</translation>
    </message>
    <message>
        <source>Message signed.</source>
        <translation>მესიჯი ხელმოწერილია.</translation>
    </message>
    <message>
        <source>The signature could not be decoded.</source>
        <translation>ხელმოწერის დეკოდირება ვერ ხერხდება.</translation>
    </message>
    <message>
        <source>Please check the signature and try again.</source>
        <translation>შეამოწმეთ ხელმოწერა და სცადეთ ხელახლა.</translation>
    </message>
    <message>
        <source>The signature did not match the message digest.</source>
        <translation>ხელმოწერა არ შეესაბამება მესიჯის დაიჯესტს.</translation>
    </message>
    <message>
        <source>Message verification failed.</source>
        <translation>მესიჯის ვერიფიკაცია ვერ მოხერხდა.</translation>
    </message>
    <message>
        <source>Message verified.</source>
        <translation>მესიჯი ვერიფიცირებულია.</translation>
    </message>
</context>
<context>
    <name>TrafficGraphWidget</name>
    <message>
        <source>KB/s</source>
        <translation>KB/s</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Open until %1</source>
        <translation>ღია იქნება სანამ %1</translation>
    </message>
    <message>
        <source>%1/unconfirmed</source>
        <translation>%1/დაუდასტურებელია</translation>
    </message>
    <message>
        <source>%1 confirmations</source>
        <translation>%1 დადასტურებულია</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>სტატუსი</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>თარიღი</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>წყარო</translation>
    </message>
    <message>
        <source>Generated</source>
        <translation>გენერირებულია</translation>
    </message>
    <message>
        <source>From</source>
        <translation>გამგზავნი</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>უცნობია</translation>
    </message>
    <message>
        <source>To</source>
        <translation>მიმღები</translation>
    </message>
    <message>
        <source>own address</source>
        <translation>საკუთარი მისამართი</translation>
    </message>
    <message>
        <source>label</source>
        <translation>ნიშნული</translation>
    </message>
    <message>
        <source>Credit</source>
        <translation>კრედიტი</translation>
    </message>
    <message>
        <source>not accepted</source>
        <translation>უარყოფილია</translation>
    </message>
    <message>
        <source>Debit</source>
        <translation>დებიტი</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>ტრანსაქციის საფასური - საკომისიო</translation>
    </message>
    <message>
        <source>Net amount</source>
        <translation>სუფთა თანხა</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>მესიჯი</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>შენიშვნა</translation>
    </message>
    <message>
        <source>Transaction ID</source>
        <translation>ტრანსაქციის ID</translation>
    </message>
    <message>
        <source>Merchant</source>
        <translation>გამყიდველი</translation>
    </message>
    <message>
        <source>Generated coins must mature %1 blocks before they can be spent. When you generated this block, it was broadcast to the network to be added to the block chain. If it fails to get into the chain, its state will change to "not accepted" and it won't be spendable. This may occasionally happen if another node generates a block within a few seconds of yours.</source>
        <translation>გენერირებული მონეტები გასაგზავნად მომწიფდება %1 ბლოკის შემდეგ. ეს ბლოკი გენერირების შემდეგ გავრცელებულ იქნა ქსელში ბლოკთა ჯაჭვზე დასამატებლად. თუ ის ვერ ჩაჯდა ჯაჭვში, მიეცემა სტატუსი "უარყოფილია" და ამ მონეტებს ვერ გამოიყენებთ. ასეთი რამ შეიძლება მოხდეს, თუ რომელიმე კვანძმა რამდენიმე წამით დაგასწროთ ბლოკის გენერირება.</translation>
    </message>
    <message>
        <source>Debug information</source>
        <translation>დახვეწის ინფორმაცია</translation>
    </message>
    <message>
        <source>Transaction</source>
        <translation>ტრანსაქცია</translation>
    </message>
    <message>
        <source>Inputs</source>
        <translation>ხარჯები</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>თანხა</translation>
    </message>
    <message>
        <source>true</source>
        <translation>ჭეშმარიტი</translation>
    </message>
    <message>
        <source>false</source>
        <translation>მცდარი</translation>
    </message>
</context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>ტრანსაქციის დაწვრილებითი აღწერილობა</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>თარიღი</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>ტიპი</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>ნიშნული</translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>ღია იქნება სანამ %1</translation>
    </message>
    <message>
        <source>Unconfirmed</source>
        <translation>დაუდასტურებელია</translation>
    </message>
    <message>
        <source>Confirming (%1 of %2 recommended confirmations)</source>
        <translation>დადასტურებულია (%1,  რეკომენდებულია %2)</translation>
    </message>
    <message>
        <source>Confirmed (%1 confirmations)</source>
        <translation>დადასტურებულია (%1დასტური)</translation>
    </message>
    <message>
        <source>Conflicted</source>
        <translation>კონფლიქტშია</translation>
    </message>
    <message>
        <source>Immature (%1 confirmations, will be available after %2)</source>
        <translation>არ არის მომწიფებული (%1 დასტური, საჭიროა სულ %2)</translation>
    </message>
    <message>
        <source>Generated but not accepted</source>
        <translation>გენერირებულია, მაგრამ უარყოფილია</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>შემოსულია</translation>
    </message>
    <message>
        <source>Received from</source>
        <translation>გამომგზავნი</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>გაგზავნილია</translation>
    </message>
    <message>
        <source>Payment to yourself</source>
        <translation>გადახდილია საკუთარი თავისათვის</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>მოპოვებულია</translation>
    </message>
    <message>
        <source>(n/a)</source>
        <translation>(მიუწვდ.)</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(ნიშნული არ არის)</translation>
    </message>
    <message>
        <source>Transaction status. Hover over this field to show number of confirmations.</source>
        <translation>ტრანსაქციის სტატუსი. ველზე კურსორის შეყვანისას გამოჩნდება დასტურების რაოდენობა.</translation>
    </message>
    <message>
        <source>Date and time that the transaction was received.</source>
        <translation>ტრანსაქციის მიღების თარიღი და დრო.</translation>
    </message>
    <message>
        <source>Type of transaction.</source>
        <translation>ტრანსაქციის ტიპი.</translation>
    </message>
    <message>
        <source>Amount removed from or added to balance.</source>
        <translation>ბალანსიდან მოხსნილი ან დამატებული თანხა.</translation>
    </message>
</context>
<context>
    <name>TransactionView</name>
    <message>
        <source>All</source>
        <translation>ყველა</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>დღეს</translation>
    </message>
    <message>
        <source>This week</source>
        <translation>ამ კვირის</translation>
    </message>
    <message>
        <source>This month</source>
        <translation>ამ თვის</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>ბოლო თვის</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>ამ წლის</translation>
    </message>
    <message>
        <source>Range...</source>
        <translation>შუალედი...</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>შემოსულია</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>გაგზავნილია</translation>
    </message>
    <message>
        <source>To yourself</source>
        <translation>საკუთარი თავისათვის</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>მოპოვებულია</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>სხვა</translation>
    </message>
    <message>
        <source>Min amount</source>
        <translation>მინ. თანხა</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>მისამართის კოპირება</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>ლეიბლის კოპირება</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>რაოდენობის კოპირება</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>ტრანსაქციის ID-ს კოპირება</translation>
    </message>
    <message>
        <source>Edit label</source>
        <translation>ნიშნულის რედაქტირება</translation>
    </message>
    <message>
        <source>Show transaction details</source>
        <translation>ტრანსაქციის დეტალების ჩვენება</translation>
    </message>
    <message>
        <source>Export Transaction History</source>
        <translation>ტრანსაქციების ისტორიის ექსპორტი</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>CSV ფორმატის ფაილი (*.csv)</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>დადასტურებულია</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>თარიღი</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>ტიპი</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>ნიშნული</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>მისამართი</translation>
    </message>
    <message>
        <source>ID</source>
        <translation>ID</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>ექპორტი ვერ განხორციელდა</translation>
    </message>
    <message>
        <source>There was an error trying to save the transaction history to %1.</source>
        <translation>შეცდომა %1-ში ტრანსაქციების შენახვის მცდელობისას.</translation>
    </message>
    <message>
        <source>Exporting Successful</source>
        <translation>ეხპორტი განხორციელებულია</translation>
    </message>
    <message>
        <source>The transaction history was successfully saved to %1.</source>
        <translation>ტრანსაქციების ისტორია შენახულია %1-ში.</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation>შუალედი:</translation>
    </message>
    <message>
        <source>to</source>
        <translation>-</translation>
    </message>
</context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletController</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    <message>
        <source>Send Coins</source>
        <translation>მონეტების გაგზავნა</translation>
    </message>
    <message>
        <source>default wallet</source>
        <translation>ნაგულისხმევი საფულე</translation>
    </message>
</context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;ექსპორტი</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>ამ ბარათიდან მონაცემების ექსპორტი ფაილში</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>შეცდომა</translation>
    </message>
    <message>
        <source>Backup Wallet</source>
        <translation>საფულის არქივირება</translation>
    </message>
    <message>
        <source>Wallet Data (*.dat)</source>
        <translation>საფულის მონაცემები (*.dat)</translation>
    </message>
    <message>
        <source>Backup Failed</source>
        <translation>არქივირება ვერ მოხერხდა</translation>
    </message>
    <message>
        <source>There was an error trying to save the wallet data to %1.</source>
        <translation>შეცდომა %1-ში საფულის მონაცემების შენახვის მცდელობისას.</translation>
    </message>
    <message>
        <source>Backup Successful</source>
        <translation>არქივირება შესრულებულია</translation>
    </message>
    <message>
        <source>The wallet data was successfully saved to %1.</source>
        <translation>საფულის მონაცემები შენახულია %1-ში.</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>This is a pre-release test build - use at your own risk - do not use for mining or merchant applications</source>
        <translation>ეს არის წინასწარი სატესტო ვერსია - გამოიყენეთ საკუთარი რისკით - არ გამოიყენოთ მოპოვებისა ან კომერციული მიზნებისათვის</translation>
    </message>
    <message>
        <source>Warning: The network does not appear to fully agree! Some miners appear to be experiencing issues.</source>
        <translation>ყურადღება: ქსელში შეუთანხმებლობაა. შესაძლოა ცალკეულ მომპოვებლებს პრობლემები ექმნებათ!</translation>
    </message>
    <message>
        <source>Warning: We do not appear to fully agree with our peers! You may need to upgrade, or other nodes may need to upgrade.</source>
        <translation>ყურადღება: ჩვენ არ ვეთანხმებით ყველა პირს. შესაძლოა თქვენ ან სხვა კვანძებს განახლება გჭირდებათ.</translation>
    </message>
    <message>
        <source>Corrupted block database detected</source>
        <translation>შენიშნულია ბლოკთა ბაზის დაზიანება</translation>
    </message>
    <message>
        <source>Do you want to rebuild the block database now?</source>
        <translation>გავუშვათ ბლოკთა ბაზის ხელახლა აგება ეხლა?</translation>
    </message>
    <message>
        <source>Error initializing block database</source>
        <translation>ვერ ინიციალიზდება ბლოკების ბაზა</translation>
    </message>
    <message>
        <source>Error initializing wallet database environment %s!</source>
        <translation>ვერ ინიციალიზდება საფულის ბაზის გარემო %s!</translation>
    </message>
    <message>
        <source>Error loading block database</source>
        <translation>არ იტვირთება ბლოკების ბაზა</translation>
    </message>
    <message>
        <source>Error opening block database</source>
        <translation>ბლოკთა ბაზის შექმნა ვერ მოხერხდა</translation>
    </message>
    <message>
        <source>Failed to listen on any port. Use -listen=0 if you want this.</source>
        <translation>ვერ ხერხდება პორტების მიყურადება. თუ გსურთ, გამოიყენეთ -listen=0.</translation>
    </message>
    <message>
        <source>Incorrect or no genesis block found. Wrong datadir for network?</source>
        <translation>საწყისი ბლოკი არ არსებობს ან არასწორია. ქსელის მონაცემთა კატალოგი datadir ხომ არის არასწორი?</translation>
    </message>
    <message>
        <source>Not enough file descriptors available.</source>
        <translation>არ არის საკმარისი ფაილ-დესკრიპტორები.</translation>
    </message>
    <message>
        <source>Verifying blocks...</source>
        <translation>ბლოკების ვერიფიკაცია...</translation>
    </message>
    <message>
        <source>Signing transaction failed</source>
        <translation>ტრანსაქციების ხელმოწერა ვერ მოხერხდა</translation>
    </message>
    <message>
        <source>Transaction amount too small</source>
        <translation>ტრანსაქციების რაოდენობა ძალიან ცოტაა</translation>
    </message>
    <message>
        <source>Transaction too large</source>
        <translation>ტრანსაქცია ძალიან დიდია</translation>
    </message>
    <message>
        <source>Unknown network specified in -onlynet: '%s'</source>
        <translation>-onlynet-ში მითითებულია უცნობი ქსელი: '%s'</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>არ არის საკმარისი თანხა</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>ბლოკების ინდექსის ჩატვირთვა...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>საფულის ჩატვირთვა...</translation>
    </message>
    <message>
        <source>Cannot downgrade wallet</source>
        <translation>საფულის ძველ ვერსიაზე გადაყვანა შეუძლებელია</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>სკანირება...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>ჩატვირთვა დასრულებულია</translation>
    </message>
</context>
</TS>